@@ -6,8 +6,8 @@ my @modules = qw(
     Module::Install::AuthorTests
     Module::Install::CheckLib
     Module::Install::ReadmeFromPod
-    Module::Install::TestTarget
     Module::Install::XSUtil
+    Module::Install::Repository
 );
 
 my @missing;
